@@ -2,9 +2,9 @@ test_that("boot632plus",{
     set.seed(130971)
     dat <- SimSurv(100)
     dat$X1 <- as.factor(dat$X1)
-    Models <- list("Cox.X1"=coxph(Surv(time,status)~X1,data=dat,y=TRUE),
-                   "Cox.X2"=coxph(Surv(time,status)~X2,data=dat,y=TRUE),
-                   "Cox.X1.X2"=coxph(Surv(time,status)~X1+X2,data=dat,y=TRUE))
+    Models <- list("Cox.X1"=coxph(Surv(time,status)~X1,data=dat,x=TRUE,y=TRUE),
+                   "Cox.X2"=coxph(Surv(time,status)~X2,data=dat,x=TRUE,y=TRUE),
+                   "Cox.X1.X2"=coxph(Surv(time,status)~X1+X2,data=dat,x=TRUE,y=TRUE))
     set.seed(17100)
     PredError.632plus <- pec(object=Models,
                              formula=Surv(time,status)~X1+X2,
